# vi: ts=4 expandtab syntax=python
##############################################################################
# Copyright (c) 2008 IBM Corporation
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Eclipse Public License v1.0
# which accompanies this distribution, and is available at
# http://www.eclipse.org/legal/epl-v10.html
#
# Contributors:
# Marcos Cintron (IBM) - initial implementation
# Dave Leskovec (IBM) - fix double inclusion of first file in writeManifest
##############################################################################
import os
import re

import Ovf
from OvfReferencedFile import OvfReferencedFile


def getReferencedFilesFromManifest(fileName):
    """
    get a list of OvfReferencedFile objects mentioned in OVF Manifest file
    @type  fileName: string
    @param fileName: path to a file to read Manifest file from
    @rtype : list of OvfReferencedFile objects
    @return: list of OvfReferencedFile objects that appear in manifest
    """
    files = []
    mf_re = re.compile(r'^SHA1 *\((?P<href>.+)\) *= *(?P<checksum>[A-Za-z0-9]+)$')
    mf = open(fileName, 'r')
    for line in mf:
        match = mf_re.match(line.strip())
        if match:
            href = match.group('href')
            checksum = match.group('checksum')
            path = Ovf.href2abspath(href, fileName)
            files.append(OvfReferencedFile(path, href, checksum))
    mf.close()
    return files


def writeManifestFromReferencedFilesList(fileName, refList):
    """
    Write a OVF Manifest file from a list of ReferencedFile objects
    @type  fileName: string
    @param fileName: path to a file to write Manifest file to
    @type  refList: list of OvfReferencedFile objects
    @param refList: each of the OvfReferencedFile objects will appear in the manifest
    """
    mf = open(fileName, 'w+')
    for currFile in refList:
        if currFile.checksum is None:
            currFile.doChecksum()
        mf.write('SHA1(%s)= %s\n' % (currFile.href, currFile.checksum))
    mf.close()
